package com.example.drawernavigator;

import android.app.Activity;
import android.content.res.Configuration;
import android.os.Bundle;
import android.support.v4.app.ActionBarDrawerToggle;
import android.support.v4.widget.DrawerLayout;
import android.view.KeyEvent;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;
import android.widget.Toast;

public class MainActivity extends Activity {

	private String[] navItems = {
		"Tiger(ȣ)", 
		"Monkey()", 
		"Lion()",
		"Jaguar(Ծ)"
	};
	
	private ListView lvNavList = null;
	private DrawerLayout dlDrawer = null;
	private ActionBarDrawerToggle dtToggle = null;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);
		
		lvNavList = (ListView)findViewById(R.id.lv_activity_main_nav_list);

		lvNavList.setAdapter(
			new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, navItems)
		);
		
		dlDrawer = (DrawerLayout)findViewById(R.id.dl_activity_main_drawer);
		dtToggle = new ActionBarDrawerToggle(this, dlDrawer, 
				R.drawable.ic_drawer, R.string.open_drawer, R.string.close_drawer) {
			@Override
			public void onDrawerClosed(View drawerView) {
				super.onDrawerClosed(drawerView);
			}
			
			@Override
			public void onDrawerOpened(View drawerView) {
				super.onDrawerOpened(drawerView);
			}
		};
		
		dlDrawer.setDrawerListener(dtToggle);
		getActionBar().setDisplayHomeAsUpEnabled(true);
		
		lvNavList.setOnItemClickListener(new DrawerItemClickListener());
	}

	private class DrawerItemClickListener implements ListView.OnItemClickListener {
		@Override
		public void onItemClick(AdapterView<?> adapter, View view, int position, long id) {
			Toast.makeText(MainActivity.this, navItems[position], Toast.LENGTH_SHORT).show();
			
			dlDrawer.closeDrawer(lvNavList);
		}
	};
	
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.main, menu);
		return true;
	}

	protected void onPostCreate(Bundle savedInstanceState){
	    super.onPostCreate(savedInstanceState);
	    dtToggle.syncState();
	}

	@Override
	public void onConfigurationChanged(Configuration newConfig) {
	    super.onConfigurationChanged(newConfig);
	    dtToggle.onConfigurationChanged(newConfig);
	}
	 
	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
	    if(dtToggle.onOptionsItemSelected(item)){
	        return true;
	    }
	    
	    return super.onOptionsItemSelected(item);
	}
	
	@Override
	public boolean onKeyUp(int keyCode, KeyEvent event) {
	    if (keyCode == KeyEvent.KEYCODE_MENU) {
	    	if(dlDrawer.isDrawerOpen(lvNavList)) dlDrawer.closeDrawer(lvNavList);
	    	else dlDrawer.openDrawer(lvNavList);
	    	
	        return true;
	    } else {
	        return super.onKeyUp(keyCode, event);
	    }
	}
}
